
#include <cstdlib>
#include <string>
#include <sstream>
#include <iostream>
#include <ctime>
using namespace std;

const int BASE = 1000000000;

int pow10 [] = {1, 10, 100, 1000, 10000, 100000, 1000000, 10000000, 100000000, 1000000000};

clock_t start;

struct BigInteger
{
  int m [8];
  
  BigInteger (int value = 0)
  {
    memset (m, 0, sizeof (m));
    m [0] = value;
  }
  
  void output ()
  {
    int i = 7;
    while (i > 0 && m [i] == 0) --i;
    if (i == 0)
      printf ("%d\n", m [i]);
    else
    {
      printf ("%d", m [i]);
      --i;
      while (true)
      {
        if (i < 0)
          break;
        printf ("%09d", m [i]);
        --i;
      }
      printf ("\n");
    }
  }
  
  void input (string s)
  {
    //char s [64];
    //scanf ("%s", s);
    //int len = strlen (s);
    int len = s.size ();
//    reverse (s, s + len);
    reverse (s.begin (), s.end ());
    
    memset (m, 0, sizeof (m));
    int dig = 0, got = 0;
    for (int i = 0; i < len; ++i)
    {
      m [dig] += pow10 [got++] * (s [i] - '0');
      if (got == 9)
      {
        got = 0;
        ++dig;
      }
    }
  }
};

inline bool add (int &a, int b)
{
  a += b;
  if (a >= BASE)
  {
    a -= BASE;
    return true;
  }
  return false;
}
inline BigInteger operator+ (BigInteger a, BigInteger b)
{
  BigInteger res (0);
  for (int i = 0; i < 8; ++i)
  {
    if (add (res.m [i], a.m [i])) ++res.m [i + 1];
    if (add (res.m [i], b.m [i])) ++res.m [i + 1];
  }
  return res;
}
inline bool operator< (BigInteger a, BigInteger b)
{
  int i = 7;
  while (i > 0 && a.m [i] == b.m [i]) --i;
  return a.m [i] < b.m [i];
}

BigInteger res [256];

void decrease (BigInteger &b)
{
  int i = 0;
  while (true)
  {
    if (--b.m [i] < 0)
    {
      --b.m [i + 1];
      b.m [i] += BASE;
      ++i;
    }
    else
      break;
  }
}

inline long long random (long long x)
{
  long long res = 0;
  for (int i = 0; i < 4; ++i)
  {
    res <<= 16;
    res += rand ();
  }
  return res % x;
}
inline long long getRandom (long long a, long long b)
{
  return a + random (b - a + 1);
}

inline int get (long long x)
{
  int res = 0;
  while (x > 1)
  {
    ++res;
    if (x % 3 == 0)
    {
      x /= 3;
      goto next;
    }
    
    if (x % 2 == 0)
    {
      x /= 2;
      goto next;
    }
    
    ++x;
    
    next: ;
  }
  return res;
}

int good = 0;

inline bool check_time ()
{
  if (++good % 1000)
    return true;
  if ((0.0 + clock () - start) / CLOCKS_PER_SEC > 8.5)
    return false;
  return true;
}
int main ()
{
  start = clock ();
  
  string aa, bb;
  cin >> aa >> bb;
  BigInteger a, b;
  a.input (aa); decrease (a);
  b.input (bb); b = b + BigInteger (1);

  res [0] = BigInteger (1);
  res [1] = BigInteger (2);
  res [2] = BigInteger (4);
  res [3] = BigInteger (5);
  res [4] = BigInteger (7);
  
  for (int i = 5; i < 256; ++i)
  {
    if (i & 1)
      res [i] = res [i - 1] + res [i - 1];
    else
    {
      res [i] = res [i - 1];
      decrease (res [i]);
    }
  }
  
  
  bool any = false;
  BigInteger most;
  
  for (int i = 0; i < 256; ++i)
  {
    if (a < res [i])
      if (res [i] < b)
      {
        any = true;
        most = res [i];
      }
  }
  
  if (any)
    most.output ();
  else if (bb.size () <= 18)
  {
    long long b, e;
    stringstream stream;
    stream << aa << " " << bb;
    stream >> b >> e;
    
    int by = -1;
    long long most = -1;
    long long now;
    while (check_time ())
    {
      now = getRandom (b, e);
      if (get (now) > by)
      {
        by = get (now);
        most = now;
      }
    }
    cout << most << endl;
  }
  else
  {
    cout << bb << endl;
  }
  return 0;
}
